AegisRT

Evals ()
No runs yet
No run selected
Select a run from the sidebar to evaluate or investigate it
Run `aegisrt run -c aegisrt.yaml` to get started

## Security Probes

## Suites

## Compare Runs

Need at least two runs.
Baseline
Compare
Delete Eval
Remove this saved run?
This removes the run from the dashboard list and compare views.
Run
Timestamp
Current behavior deletes the stored run record. Artifact files under .aegisrt/runs/ are not removed by this UI action.